# Video Representation Extractor

![logo](logo.png)

Documentation at: [link](https://video-representations-extractor.gitlab.io/video-representations-extractor/).

See the usage and installation page: [link](https://video-representations-extractor.gitlab.io/video-representations-extractor/basics/introduction-and-installation.html#installation).

Google colab showcases:
- Real time Semantic Segmentation on youtube videos: [link](https://colab.research.google.com/drive/1-Zc7qEC7k7KnCuq-LOnNy9hoMfQBJA9O#scrollTo=TR5G9bBhY9_k)
- Full example from a single test video to complex extracted representations: [link](https://colab.research.google.com/drive/1vAp71H-TLewhF56odv33TkmGwwhuoFJ-?usp=sharing)
